@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun <syp at umd dot edu>
 # License: BSD 2-clause
-# Last Change: Tue Sep 22, 2020 at 02:36 AM +0800
+# Last Change: Thu Mar 11, 2021 at 12:26 AM +0100
 
 import pytest
 import os
@@ -26,34 +26,34 @@ SAMPLE_ROOT = os.path.join(PARDIR, 'samples', 'sample.root')
 def test_BabyConfigParser_update_config():
     config = {'a': 1, 'b': 2, 'e': [1, 2]}
     update = {'a': 2, 'c': 3, 'e': [3]}
-    update_config(config, update)
+    result = update_config(config, update)
 
-    assert config['a'] == 3
-    assert config['b'] == 2
-    assert config['c'] == 3
-    assert config['e'] == [1, 2, 3]
+    assert result['a'] == 2
+    assert result['b'] == 2
+    assert result['c'] == 3
+    assert result['e'] == [1, 2, 3]
 
 
 def test_BabyConfigParser_update_config_merge_dict():
     config = {'a': 1, 'b': 2, 'e': {1: 2, 3: 4}}
     update = {'a': 2, 'c': 3, 'e': {1: 3, 2: 4}}
-    update_config(config, update)
+    result = update_config(config, update)
 
-    assert config['a'] == 3
-    assert config['b'] == 2
-    assert config['c'] == 3
-    assert config['e'] == {1: 3, 2: 4, 3: 4}
+    assert result['a'] == 2
+    assert result['b'] == 2
+    assert result['c'] == 3
+    assert result['e'] == {1: 3, 2: 4, 3: 4}
 
 
 def test_BabyConfigParser_update_config_no_merge():
     config = {'a': 1, 'b': 2, 'e': [1, 2]}
     update = {'a': 2, 'c': 3, 'e': [3]}
-    update_config(config, update, merge=False)
+    result = update_config(config, update, merge=False)
 
-    assert config['a'] == 1
-    assert config['b'] == 2
-    assert config['c'] == 3
-    assert config['e'] == [1, 2]
+    assert result['a'] == 2
+    assert result['b'] == 2
+    assert result['c'] == 3
+    assert result['e'] == [3]
 
 
 ##################
@@ -146,13 +146,12 @@ def test_SimpleMaker_read(default_SimpleMaker):
 
 def test_SimpleMaker_dump_scalar(default_SimpleMaker):
     result = default_SimpleMaker.dump(SAMPLE_ROOT)
-    assert result['TupleB0/DecayTree']['CaloBremChi2'] == 'Float_t'
+    assert result['TupleB0/DecayTree']['CaloBremChi2'] == 'float'
 
 
-@pytest.mark.xfail(reason="Don't know how to detect vector with ROOT C++ code.")
 def test_SimpleMaker_dump_vector(default_SimpleMaker):
     result = default_SimpleMaker.dump(SAMPLE_ROOT)
-    assert result['TupleB0/DecayTree']['Y_OWNPV_COV_'] == 'vector<Float_t>'
+    assert result['TupleB0/DecayTree']['Y_OWNPV_COV_'] == 'float[3][3]'
 
 
 def test_SimpleMaker_reformat(default_SimpleMaker):
